@@ -42,19 +42,19 @@ class NotificationQuerySet(QuerySet):
         )
 
 
-class NoticeManager(object):
+class NotificationManager(object):
     @staticmethod
-    def is_notice_allowed(user, channel, event):
+    def is_notification_enabled(user, channel, event):
         event_identifier = event.lower()
 
-        notices_settings = user.notices_settings
+        notification_settings = user.notification_settings
 
         # support for django-jsonfield which breaks native PostgreSQL functionality
-        if isinstance(notices_settings, str):
-            notices_settings = json.loads(notices_settings)
+        if isinstance(notification_settings, str):
+            notification_settings = json.loads(notification_settings)
 
         try:
-            return notices_settings[channel][event_identifier]
+            return notification_settings[channel][event_identifier]
         except (KeyError, TypeError):
             return True
 
@@ -63,31 +63,33 @@ class NoticeManager(object):
         if not recipient.is_active:
             return
 
-        registered_for_notification = NoticeManager.is_notice_allowed(recipient, 'notification', event)
-        hash = None
+        from whistle.models import Notification
 
-        if registered_for_notification:
-            from whistle.models import Notification
+        # create new notification object
+        notification = Notification(
+            recipient=recipient,
+            event=event,
+            actor=actor,
+            object=object,
+            target=target,
+            details=details
+        )
 
-            # create new notification object
-            notification = Notification.objects.create(
-                recipient=recipient,
-                event=event,
-                actor=actor,
-                object=object,
-                target=target,
-                details=details
-            )
-
-            hash = notification.hash
+        # web
+        if NotificationManager.is_notification_enabled(recipient, 'notification', event):
+            # save notification to DB
+            notification.save()
 
             # clear user notifications cache
             recipient.clear_unread_notifications_cache()
 
-        registered_for_email = NoticeManager.is_notice_allowed(recipient, 'mail', event)
+        # email
+        if NotificationManager.is_notification_enabled(recipient, 'mail', event):
+            notification.send_mail(request)
 
-        if registered_for_email:
-            EmailManager.send_mail(request, recipient, event, actor, object, target, details, hash)
+        # push
+        if NotificationManager.is_notification_enabled(recipient, 'push', event):
+            notification.push(request)
 
     @staticmethod
     def get_description(event, actor, object, target, pass_variables=True):
@@ -147,10 +149,10 @@ class EmailManager(object):
         recipient_list = [recipient.email]
 
         # description
-        description = NoticeManager.get_description(event, actor, object, target, True)
+        description = NotificationManager.get_description(event, actor, object, target, True)
 
         # subject
-        short_description = NoticeManager.get_description(event, actor, object, target, False)
+        short_description = NotificationManager.get_description(event, actor, object, target, False)
 
         try:
             site = get_current_site(request)
